@@ -43,7 +43,7 @@ class AliUploadLink(object):
 class AliKey(object):
     def __init__(self):
         super().__init__()
-        self.chunkSize = 1024 * 1024 * 10
+        self.chunkSize = 1024 * 1024 * 0.5
         self.driveId = ''
         self.refreshToken = ''
         self.headers = None
